---
title: <span class="badge object-type-scalar"></span> Volt
---
# <span class="badge object-type-scalar"></span> Volt

Energy: Volt (V)

## Definition

```python
# Energy: Volt (V)
Volt: typing.Literal["volt"] = "volt"
```
